
.. _flex:

Adobe Flex properties files
***************************

.. versionadded:: 1.8

Adobe Flex applications use :doc:`Java properties <properties>` encoded in UTF-8.
The :doc:`prop2po </commands/prop2po>` and po2prop commands are used for conversion.

.. _flex#references:

References
==========

* `Description for Adobe Flex properties files
  <http://help.adobe.com/en_US/Flex/4.0/UsingSDK/WS2db454920e96a9e51e63e3d11c0bf69084-7f2d.html>`_
